@@ -7,12 +7,11 @@ use warnings;
 
 use version; our $VERSION = version->declare("v1.0.8");
 
-use Zonemaster::Engine;
-
 use Carp;
 use List::MoreUtils qw[none any];
 use Locale::TextDomain qw[Zonemaster-Engine];
 use Readonly;
+
 use Zonemaster::Engine::Recursor;
 use Zonemaster::Engine::Constants qw[:addresses :ip];
 use Zonemaster::Engine::TestMethods;
@@ -103,7 +102,7 @@ Readonly my %TAG_DESCRIPTIONS => (
     },
     NO_RESPONSE_PTR_QUERY => sub {
         __x    # ADDRESS:NO_RESPONSE_PTR_QUERY
-          'No response from nameserver(s) on PTR query ({reverse}).', @_;
+          'No response from nameserver(s) on PTR query ({domain}).', @_;
     },
     TEST_CASE_END => sub {
         __x    # ADDRESS:TEST_CASE_END
@@ -221,7 +220,7 @@ sub address02 {
             push @results,
               info(
                 NO_RESPONSE_PTR_QUERY => {
-                    reverse => $ptr_query,
+                    domain => $ptr_query,
                 }
               );
         }
@@ -289,7 +288,7 @@ sub address03 {
             push @results,
               info(
                 NO_RESPONSE_PTR_QUERY => {
-                    reverse => $ptr_query,
+                    domain => $ptr_query,
                 }
               );
         }
