@@ -5,14 +5,13 @@ use 5.014002;
 use strict;
 use warnings;
 
-use version; our $VERSION = version->declare("v1.0.17");
-
-use Zonemaster::Engine;
+use version; our $VERSION = version->declare("v1.0.18");
 
 use Carp;
 use List::MoreUtils qw[any none];
 use Locale::TextDomain qw[Zonemaster-Engine];
 use Readonly;
+
 use Zonemaster::Engine::Profile;
 use Zonemaster::Engine::Constants qw[:ip :name];
 use Zonemaster::Engine::Test::Address;
@@ -668,8 +667,8 @@ sub basic04 {
                       );
                 }
                 else {
-                    my ( $ns ) = $p_ns_udp->get_records( q{NS}, q{answer} );
-                    if ( not $ns ) {
+                    my ( $ns_in_answer ) = $p_ns_udp->get_records( q{NS}, q{answer} );
+                    if ( not $ns_in_answer ) {
                         push @results,
                           info(
                             B04_MISSING_NS_RECORD => {
@@ -678,12 +677,12 @@ sub basic04 {
                           );
                     }
                     else {
-                        if ( lc($ns->owner) ne lc($name->fqdn) ) {
+                        if ( lc($ns_in_answer->owner) ne lc($name->fqdn) ) {
                             push @results,
                               info(
                                 B04_WRONG_NS_RECORD => {
                                     ns    => $ns->string,
-                                    owner => lc($ns->owner),
+                                    owner => lc($ns_in_answer->owner),
                                     name  => lc($name->fqdn)
                                 }
                               );
